Crate dbiewlite_core

Crate dbiewlite_core 

Structs

ColumnInfo
DbInfo
DuckdbBackend
IndexInfo
QueryResult
Sort
SqliteBackend
TableInfo

Enums

CellValue
Database

Functions

escape_csv
format_size
order_clause
The ORDER BY for a sorted view, shared by the paged reads and the export so a file cannot come out ordered differently from the grid it was taken from.
write_csv