Crate dbiewlite_core
dbiewlite_
core
0.4.0
All Items
Crate Items
Structs
Enums
Functions
Crate
dbiewlite_
core
Structs

Column
Info
DbInfo
Duckdb
Backend
Index
Info
Query
Result
Sort
Sqlite
Backend
Table
Info
Enums

Cell
Value
Database
Functions

escape_
csv
format_
size
order_
clause
The ORDER BY for a sorted view, shared by the paged reads and the export so a file cannot come out ordered differently from the grid it was taken from.
write_
csv